summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jingle/libjingle/talk/base/task.h')
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/base/task.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h b/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h
index c583bda8..7140b691 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/base/task.h
@@ -61,12 +61,12 @@
// might be working on something as you send it infomration, you may want
// to have a queue in the task.
//
// (3) Finally it helps manage tqparent tasks and tqchildren. If a tqparent
// task gets aborted, all the tqchildren tasks are too. The nice thing
// about this, for example, is if you have one tqparent task that
// represents, say, and Xmpp connection, then you can spawn a whole bunch
// of infinite lifetime child tasks and now worry about cleaning them up.
// When the tqparent task goes to STATE_DONE, the task engine will make
// sure all those tqchildren are aborted and get deleted.
//
// Notice that Task has a few built-in states, e.g.,
@@ -103,7 +103,7 @@ class RootTask;
class Task {
public:
- Task(Task * tqparent);
+ Task(Task * parent);
virtual ~Task() {}
void Start();
@@ -61,12 +61,12 @@
// to have a queue in the task.
//
-// (3) Finally it helps manage tqparent tasks and tqchildren. If a tqparent
+// (3) Finally it helps manage parent tasks and tqchildren. If a parent
// task gets aborted, all the tqchildren tasks are too. The nice thing
@@ -61,12 +61,12 @@
// task gets aborted, all the tqchildren tasks are too. The nice thing
-// about this, for example, is if you have one tqparent task that
+// about this, for example, is if you have one parent task that
// represents, say, and Xmpp connection, then you can spawn a whole bunch
// of infinite lifetime child tasks and now worry about cleaning them up.
@@ -61,12 +61,12 @@
// represents, say, and Xmpp connection, then you can spawn a whole bunch
// of infinite lifetime child tasks and now worry about cleaning them up.
-// When the tqparent task goes to STATE_DONE, the task engine will make
+// When the parent task goes to STATE_DONE, the task engine will make
// sure all those tqchildren are aborted and get deleted.
//